@@ -1,4 +1,9 @@
 import ast
+import logging
+
+
+logger = logging.getLogger()
+logger.debug(f'this')
 
 class FoundFSTringException(Exception):
     pass
@@ -12,14 +17,16 @@ def parse(script: str):
     log_calls = []
     for node in ast.walk(parsed):
         if isinstance(node, ast.Expr):
-            print(node)
             for child in ast.iter_child_nodes(node):
                 if isinstance(child, ast.Call):
-                    func_name = child.func.attr
+                    try:
+                        func_name = child.func.attr
+                    except AttributeError:
+                        continue
                     if func_name in ['info', 'debug', 'warning', 'error', 'exception']:
                         log_calls.append(child)
     for log_call in log_calls:
-        if isinstance(log_calls[0].args[0], ast.JoinedStr):
+        if isinstance(log_call.args[0], ast.JoinedStr):
             raise FoundFSTringException
 
     return 0
